aboutsummaryrefslogtreecommitdiff
path: root/plugins/proxy.py
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/proxy.py')
-rwxr-xr-xplugins/proxy.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/plugins/proxy.py b/plugins/proxy.py
index b2db79b0e..cf5588b24 100755
--- a/plugins/proxy.py
+++ b/plugins/proxy.py
@@ -1,13 +1,13 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# xmlrpc — helper for Python-based external (xml-rpc) ikiwiki plugins
#
# Copyright © martin f. krafft <madduck@madduck.net>
# Released under the terms of the GNU GPL version 2
#
-__name__ = 'xmlrpc'
-__description__ = 'xml-rpc-based ikiwiki plugin to process RST files'
+__name__ = 'proxy.py'
+__description__ = 'helper for Python-based external (xml-rpc) ikiwiki plugins'
__version__ = '0.1'
__author__ = 'martin f. krafft <madduck@madduck.net>'
__copyright__ = 'Copyright © ' + __author__
@@ -1,13 +1,13 @@
# -*- coding: utf-8 -*-
#
-# xmlrpc — helper for Python-based external (xml-rpc) ikiwiki plugins
+# proxy.py — helper for Python-based external (xml-rpc) ikiwiki plugins
#
# Copyright © martin f. krafft <madduck@madduck.net>